@@ -28,7 +28,7 @@
 #ifndef HAVE_BACON_VIDEO_WIDGET_H
 #define HAVE_BACON_VIDEO_WIDGET_H
 
-#include <gtk/gtkeventbox.h>
+#include <gtk/gtk.h>
 /* for optical disc enumeration type */
 #include <totem-disc.h>
 
@@ -80,6 +80,7 @@ typedef enum {
 	/* Devices */
 	BVW_ERROR_DVD_ENCRYPTED,
 	BVW_ERROR_INVALID_DEVICE,
+	BVW_ERROR_DEVICE_BUSY,
 	/* Network */
 	BVW_ERROR_UNKNOWN_HOST,
 	BVW_ERROR_NETWORK_UNREACHABLE,
@@ -171,20 +172,10 @@ void bacon_video_widget_set_connection_speed     (BaconVideoWidget *bvw,
 						  int speed);
 int bacon_video_widget_get_connection_speed      (BaconVideoWidget *bvw);
 
-typedef enum {
-	BVW_CAN_PLAY_SUCCESS,
-	BVW_CAN_PLAY_MISSING_CHANNELS,
-	BVW_CAN_PLAY_MISSING_PLUGINS,
-	BVW_CAN_PLAY_UNSUPPORTED
-} BaconVideoWidgetCanPlayStatus;
-
-BaconVideoWidgetCanPlayStatus bacon_video_widget_can_play
-						 (BaconVideoWidget *bvw,
-						  TotemDiscMediaType type);
-
 gchar **bacon_video_widget_get_mrls		 (BaconVideoWidget *bvw,
 						  TotemDiscMediaType type,
-						  const char *device);
+						  const char *device,
+						  GError **error);
 void bacon_video_widget_set_subtitle_font	 (BaconVideoWidget *bvw,
 						  const char *font);
 void bacon_video_widget_set_subtitle_encoding	 (BaconVideoWidget *bvw,
@@ -222,14 +213,14 @@ void bacon_video_widget_get_metadata		 (BaconVideoWidget *bvw,
 
 /* Visualisation functions */
 typedef enum {
-	VISUAL_SMALL,
+	VISUAL_SMALL = 0,
 	VISUAL_NORMAL,
 	VISUAL_LARGE,
 	VISUAL_EXTRA_LARGE,
 	NUM_VISUAL_QUALITIES
 } VisualsQuality;
 
-gboolean bacon_video_widget_set_show_visuals	  (BaconVideoWidget *bvw,
+void bacon_video_widget_set_show_visuals	  (BaconVideoWidget *bvw,
 						   gboolean show_visuals);
 GList *bacon_video_widget_get_visuals_list	  (BaconVideoWidget *bvw);
 gboolean bacon_video_widget_set_visuals		  (BaconVideoWidget *bvw,
@@ -253,6 +244,7 @@ typedef enum {
 	BVW_RATIO_DVB = 4
 } BaconVideoWidgetAspectRatio;
 
+gboolean bacon_video_widget_can_deinterlace	 (BaconVideoWidget *bvw);
 void bacon_video_widget_set_deinterlacing        (BaconVideoWidget *bvw,
 						  gboolean deinterlace);
 gboolean bacon_video_widget_get_deinterlacing    (BaconVideoWidget *bvw);
@@ -266,7 +258,6 @@ BaconVideoWidgetAspectRatio bacon_video_widget_get_aspect_ratio
 void bacon_video_widget_set_scale_ratio          (BaconVideoWidget *bvw,
 						  float ratio);
 
-gboolean bacon_video_widget_can_set_zoom	 (BaconVideoWidget *bvw);
 void bacon_video_widget_set_zoom		 (BaconVideoWidget *bvw,
 						  int zoom);
 int bacon_video_widget_get_zoom			 (BaconVideoWidget *bvw);
@@ -321,20 +312,6 @@ gboolean bacon_video_widget_can_get_frames       (BaconVideoWidget *bvw,
 						  GError **error);
 GdkPixbuf *bacon_video_widget_get_current_frame (BaconVideoWidget *bvw);
 
-/* TV-Out functions */
-typedef enum {
-	TV_OUT_NONE,
-	TV_OUT_NVTV_PAL,
-	TV_OUT_NVTV_NTSC
-} TvOutType;
-
-gboolean bacon_video_widget_fullscreen_mode_available (BaconVideoWidget *bvw,
-						       TvOutType tvout);
-
-void bacon_video_widget_set_tv_out               (BaconVideoWidget *bvw,
-						  TvOutType tvout);
-TvOutType bacon_video_widget_get_tv_out          (BaconVideoWidget *bvw);
-
 /* Audio-out functions */
 typedef enum {
 	BVW_AUDIO_SOUND_STEREO,
