@@ -49,7 +49,6 @@ struct TotemSkiptoPluginPrivate
 
 G_MODULE_EXPORT GType register_totem_plugin		(GTypeModule *module);
 
-static void totem_skipto_plugin_init			(TotemSkiptoPlugin *plugin);
 static void totem_skipto_plugin_finalize		(GObject *object);
 static gboolean impl_activate				(TotemPlugin *plugin, TotemObject *totem, GError **error);
 static void impl_deactivate				(TotemPlugin *plugin, TotemObject *totem);
@@ -218,8 +217,8 @@ impl_activate (TotemPlugin *plugin,
 
 	builder_path = totem_plugin_find_file (TOTEM_PLUGIN (plugin), "skipto.ui");
 	if (builder_path == NULL) {
-		g_set_error (error, TOTEM_PLUGIN_ERROR, TOTEM_PLUGIN_ERROR_ACTIVATION,
-				_("Could not load the \"Skip to\" dialog interface."));
+		g_set_error_literal (error, TOTEM_PLUGIN_ERROR, TOTEM_PLUGIN_ERROR_ACTIVATION,
+                                     _("Could not load the \"Skip to\" dialog interface."));
 		return FALSE;
 	}
 	g_free (builder_path);
