@@ -14,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public
    License along with the Gnome Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301  USA.
 
    Author: Bastien Nocera <hadess@hadess.net>
  */
@@ -27,6 +27,8 @@
 
 G_BEGIN_DECLS
 
+#define TOTEM_MAX_RECENT_ITEM_LEN 40
+
 void totem_ui_manager_setup (Totem *totem);
 
 void totem_sublang_update (Totem *totem);
@@ -35,7 +37,7 @@ void totem_sublang_exit (Totem *totem);
 void totem_setup_play_disc (Totem *totem);
 
 void totem_setup_recent (Totem *totem);
-void totem_action_add_recent (Totem *totem, const char *filename);
+void totem_action_add_recent (Totem *totem, const char *uri);
 
 G_END_DECLS
 
